Package: DynareR
Type: Package
Title: Bringing the Power of 'Dynare' to 'R', 'R Markdown', and
        'Quarto'
Version: 0.1.4
Authors@R: c(
    person("Sagiru", "Mati", role = c("aut", "cre"), email = "sagirumati@gmail.com",comment=c(ORCID="0000-0003-1413-3974")))
Maintainer: Sagiru Mati <sagirumati@gmail.com>
Description: It allows running 'Dynare' program from base R, R Markdown and Quarto. 'Dynare' is a software platform for handling a wide class of economic models, in particular dynamic stochastic general equilibrium ('DSGE') and overlapping generations ('OLG') models.  This package does not only integrate R and Dynare but also serves as a 'Dynare' Knit-Engine for 'knitr' package. The package requires 'Dynare' (<https://www.dynare.org/>) and 'Octave' (<https://www.octave.org/download.html>).  Write all your 'Dynare' commands in R or R Markdown chunk.
Depends: R (>= 3.2.3)
Imports: knitr (>= 1.20),magrittr
SystemRequirements: Dynare, Octave
Suggests: rmarkdown
License: GPL
URL: https://CRAN.R-project.org/package=DynareR
BugReports: https://github.com/sagirumati/DynareR/issues
Encoding: UTF-8
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-09-30 12:19:14 UTC; SMATI
Repository: CRAN
Date/Publication: 2023-09-30 22:42:53 UTC
RoxygenNote: 7.2.3
Author: Sagiru Mati [aut, cre] (<https://orcid.org/0000-0003-1413-3974>)
Built: R 4.2.0; ; 2023-10-01 01:37:03 UTC; unix
