# Generated by roxygen2: do not edit by hand

export(add_matlab_path)
export(add_path)
export(eng_dynare)
export(import_log)
export(include_IRF)
export(input_tex)
export(run_dynare)
export(run_models)
export(set_dynare_version)
export(set_octave_path)
export(write_dyn)
export(write_mod)
import(knitr)
import(magrittr)
import(utils)
